@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
+from botocore.response import StreamingBody
+
 from .literals import (
     AssociationComplianceSeverityType,
     AssociationExecutionFilterKeyType,
@@ -2439,7 +2441,7 @@ MaintenanceWindowLambdaParametersTypeDef = TypedDict(
     {
         "ClientContext": str,
         "Qualifier": str,
-        "Payload": Union[bytes, IO[bytes]],
+        "Payload": Union[bytes, IO[bytes], StreamingBody],
     },
     total=False,
 )
